@@ -460,20 +460,22 @@ class VariableClClientUserMountData(ReadonlyTableVariable):
     def get(self, hr=HumanReadable.No):
         home = path.split(self.Get('ur_home_path'))[0]
         envFile = self.Get('cl_env_server_path')
+        samba_host = self.Get('sr_samba_host')
+        ftp_host = convertEnv().getVar("ftp", "host")
 
         def generate():
             yield (
                 "share", "share", path.join(self.Get('ur_home_path'), "Share"),
-                self.Get('cl_remote_host'))
+                samba_host)
             yield (
                 "unix", "unix", path.join(home, ".%s" % self.Get('ur_login')),
-                self.Get('cl_remote_host'))
+                samba_host)
             yield (
                 "homes", "homes", path.join(self.Get('ur_home_path'), "Home"),
-                self.Get('cl_remote_host'))
-            if convertEnv().getVar("ftp", "host"):
+                samba_host)
+            if ftp_host:
                 yield ("ftp", "ftp", path.join(self.Get('ur_home_path'), "FTP"),
-                       self.Get('cl_remote_host'))
+                       ftp_host)
             else:
                 yield ("ftp", '', '', '')
             if self.Get('cl_replication_host'):
@@ -750,3 +752,10 @@ class VariableClSyncMovedSet(Variable):
     """
     type = "bool"
     value = "on"
+
+class VariableSrSambaHost(Variable):
+    """
+    Хост на котором находятся samba ресурсы
+    """
+    def get(self):
+        return self.Get('cl_remote_host') or ''
